/******************************************************************************

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

#ifndef DRIVER_H
#define DRIVER_H

#include <ctime>

#include <boost/random/bernoulli_distribution.hpp>

#include "wordlist.hpp"
#include "settings.hpp"
#include "inputreader.hpp"
#include "damerau.hpp"
#include "splitcompound.hpp"
#include "introducerlist.hpp"
#include "sounderror.hpp"

class Driver {
public:
     Driver(Wordlist&, Settings &, InputReader &, Damerau &, SplitCompound &, IntroducerList &, SoundError &);
     void createErrors();
private:
    typedef boost::mt19937 base_generator_type;
    typedef boost::bernoulli_distribution<> distribution_type;
    typedef boost::variate_generator<base_generator_type, distribution_type> bernoulli;

     Wordlist &wordlist;
     Settings &settings;
     InputReader &inputreader;
     Damerau &damerau;
     SplitCompound &splitCompound;
     IntroducerList &introducerlist;
     SoundError &sounderror;
     bool activeDamerau;
     bool activeSplitCompound;
     bool activeSoundError;
     std::string sentenceSeparatorTag;
    int maxErrorsInSentence;
    base_generator_type generator;
    /*boost::mt19937 generator;*/
    bernoulli random_bit_damerau;
    bernoulli random_bit_splitCompound;
    bernoulli random_bit_sounderror;
     std::list<std::pair<bernoulli,int> > random_bits_introducer;
};

#endif
