/******************************************************************************

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

#ifndef ERRORWRITER_H
#define ERRORWRITER_H

#include <iostream>
#include <fstream>
#include <string>

#include <boost/lexical_cast.hpp>

#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/framework/LocalFileFormatTarget.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>
#include <xercesc/dom/DOMWriter.hpp>

#include "wordlist.hpp"
#include "settings.hpp"
#include "utils.hpp"
#include "wordtag.hpp"
#include "mywriterfilter.hpp"

XERCES_CPP_NAMESPACE_USE

/**
 * This class writes the error messages to an XML-file.
 */
class ErrorWriter {
public:
     ErrorWriter(Wordlist&, Settings &);
     ~ErrorWriter();
     void insertInfo(char **, const std::string&, const std::string&);
     void insertDamerau(const std::string&, const int, const WordTag&, const WordTag&);
     void insertSplitCompound(const int, const WordTag&, const WordTag&, const WordTag&);
     void insertIntroduced(const std::string&, const WordTag&, const WordTag&);
     void insertIntroduced(const std::string&, int, int, int, const std::string&, int, const std::string&, int);
     void insertSoundError(const WordTag&, const WordTag&);
     void write() const;
private:
     DOMElement* addHeader(const std::string);
     void addFooter(DOMElement *elem);
     void addElement(DOMElement *, const std::string, const std::string&);
     Wordlist &wordlist;
     Settings &settings;
     std::string filename;
     std::string reportDamerau;
     std::string reportSplitCompound;
     std::string reportSoundError;
     std::string reportErrorIntroducer;
     DOMImplementation *impl;
     DOMDocument *document;
     DOMElement *root;
};

#endif
